## START: Set by rpmautospec
## (rpmautospec version 0.7.3)
## RPMAUTOSPEC: autorelease, autochangelog
%define autorelease(e:s:pb:n) %{?-p:0.}%{lua:
    release_number = 2;
    base_release_number = tonumber(rpm.expand("%{?-b*}%{!?-b:1}"));
    print(release_number + base_release_number - 1);
}%{?-e:.%{-e*}}%{?-s:.%{-s*}}%{!?-n:%{?dist}}
## END: Set by rpmautospec

# make main package noarch to run tests on all arches
# but the package is actually noarch, so don't generate debuginfo
%global debug_package %{nil}

%global desc %{expand: \
Nilearn is a Python module for fast and easy statistical learning on
NeuroImaging data.

It leverages the scikit-learn Python toolbox for multivariate statistics with
applications such as predictive modelling, classification, decoding, or
connectivity analysis.

This work is made available by a community of people, amongst which the INRIA
Parietal Project Team and the scikit-learn folks, in particular P. Gervais, A.
Abraham, V. Michel, A. Gramfort, G. Varoquaux, F. Pedregosa, B. Thirion, M.
Eickenberg, C. F. Gorgolewski, D. Bzdok, L. Esteve and B. Cipollini.

Detailed documentation is available at http://nilearn.github.io/.}

%global forgeurl https://github.com/nilearn/nilearn

Name:           python-nilearn
Version:        0.11.1
Release:        %autorelease
Summary:        Python module for fast and easy statistical learning on NeuroImaging data

%global tag %{version}
%forgemeta

# SPDX
License:        BSD-3-Clause
URL:            %forgeurl
# Use GitHub tar: pypi does not include all test data
Source:         %forgesource

# python-scikit-learn is ExcludeArch: %%{ix86}
ExcludeArch:    %{ix86}

BuildRequires:  python3-devel
BuildRequires:  %{py3_dist pytest}
BuildRequires:  git-core
# For tests
BuildRequires:  %{py3_dist matplotlib}
BuildRequires:  %{py3_dist plotly}

# Dependencies of 'plotting' extra
# To build the extra, we'd need kaleido in Fedora
Recommends:     %{py3_dist matplotlib}
Recommends:     %{py3_dist plotly}

%description
%{desc}

%package -n python3-nilearn
Summary:        %{summary}
BuildArch:      noarch

%description -n python3-nilearn
%{desc}

%prep
%forgeautosetup -p1
export SETUPTOOLS_SCM_PRETEND_VERSION='%{version}'

# Remove shebangs
find . -name "*py" -exec sed -i '/#!\/usr\/bin\/env python/ d' '{}' \;
# Remove pre-compiled files
find . -name "*pyc" -exec rm -f '{}' \;

# Correct python command
sed -i 's/python/python3/' nilearn/plotting/html_document.py
#sed -i 's/python/python3/' nilearn/plotting/glass_brain_files/generate_json.sh

# Remove pytest-reporter-html1 arguments
sed -r -i 's/--template=[^[:blank:]"]+//' pyproject.toml

%generate_buildrequires
export SETUPTOOLS_SCM_PRETEND_VERSION='%{version}'
%pyproject_buildrequires -r

%build
export SETUPTOOLS_SCM_PRETEND_VERSION='%{version}'
%pyproject_wheel

# Documentation also fetches imaging data set from online sources, so we cannot
# generate it. We include the link to the documentation in the description.

%install
%pyproject_install
%pyproject_save_files -l nilearn

%check
%ifarch x86_64
# [BUG] test_canica_square_img fails on some x86_64 machines
# https://github.com/nilearn/nilearn/issues/4876
k="${k-}${k+ and }not test_canica_square_img"
%endif

# Requires kaleido (not available in Fedora)
k="${k-}${k+ and }not test_plot_surf[plotly]"
%{pytest} -v "${k:+-k $k}" nilearn

%files -n python3-nilearn -f %{pyproject_files}
%doc README.rst

%changelog
## START: Generated by rpmautospec
* Mon Dec 23 2024 Packit <hello@packit.dev> - 0.11.1-1
- Update to 0.11.1 upstream release
- Resolves: rhbz#2333824

* Wed Dec 04 2024 Packit <hello@packit.dev> - 0.11.0-1
- Update to 0.11.0 upstream release
- Resolves: rhbz#2329939

* Fri Jul 19 2024 Fedora Release Engineering <releng@fedoraproject.org> - 0.10.4-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_41_Mass_Rebuild

* Tue Jun 18 2024 Python Maint <python-maint@redhat.com> - 0.10.4-4
- Rebuilt for Python 3.13

* Wed Apr 10 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 0.10.4-3
- F40+: Drop spec-file conditionals for 32-bit architectures

* Wed Apr 10 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 0.10.4-2
- F40+: Drop i686 support since python-scikit-learn did

* Tue Apr 09 2024 Packit <hello@packit.dev> - 0.10.4-1
- Update to 0.10.4 upstream release
- Resolves: rhbz#2274127

* Sun Feb 11 2024 Sandro <devel@penguinpee.nl> - 0.10.3-3
- Migrate to SPDX license

* Sun Feb 11 2024 Sandro <devel@penguinpee.nl> - 0.10.3-2
- Fix tests
- Add `matplotlib` and `plotly` as test dependencies
- Recommend `plotly` as well
- Re-enable tests that failed after Python 3.12 upgrade

* Mon Jan 29 2024 Packit <hello@packit.dev> - 0.10.3-1
- [packit] 0.10.3 upstream release
- Resolves rhbz#2260833

* Fri Jan 26 2024 Fedora Release Engineering <releng@fedoraproject.org> - 0.10.2-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Mon Jan 22 2024 Fedora Release Engineering <releng@fedoraproject.org> - 0.10.2-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Thu Jan 04 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 0.10.2-2
- Assert that the .dist-info directory contains a license file
- Don’t package an extra copy of AUTHORS.rst outside the .dist-info
  directory

* Sat Oct 14 2023 Ankur Sinha (Ankur Sinha Gmail) <sanjay.ankur@gmail.com> - 0.10.2-1
- feat: update to 0.10.2 (fixes rh#2241334)

* Sat Oct 14 2023 Ankur Sinha (Ankur Sinha Gmail) <sanjay.ankur@gmail.com> - 0.10.1-5
- chore: add packit

* Fri Jul 21 2023 Fedora Release Engineering <releng@fedoraproject.org> - 0.10.1-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_39_Mass_Rebuild

* Tue Jul 18 2023 Sandro <devel@penguinpee.nl> - 0.10.1-3
- Disable failing tests (RHBZ#2220358)
- Temporarily disabled a handful of failing tests

* Tue Jul 18 2023 Python Maint <python-maint@redhat.com> - 0.10.1-2
- Rebuilt for Python 3.12

* Mon May 01 2023 Ankur Sinha (Ankur Sinha Gmail) <sanjay.ankur@gmail.com> - 0.10.1-1
- feat: update to 0.10.1 (fixes rhbz#2173889)

* Sat Feb 25 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 0.10.0-4
- Fix failing test due to use of deprecated Nibabel method

* Mon Feb 06 2023 Ankur Sinha (Ankur Sinha Gmail) <sanjay.ankur@gmail.com> - 0.10.0-3
- fix: include patch to fix for python-nibabel 5.x

* Fri Jan 20 2023 Fedora Release Engineering <releng@fedoraproject.org> - 0.10.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_38_Mass_Rebuild

* Fri Jan 06 2023 Ankur Sinha (Ankur Sinha Gmail) <sanjay.ankur@gmail.com> - 0.10.0-1
- feat: update to 0.10.0 (fixes rhbz#2158756)

* Sun Oct 16 2022 Ankur Sinha (Ankur Sinha Gmail) <sanjay.ankur@gmail.com> - 0.9.2-2
- fix: disable randomly failing tests (fix rhbz#2126115)

* Sun Oct 09 2022 Ankur Sinha (Ankur Sinha Gmail) <sanjay.ankur@gmail.com> - 0.9.2-1
- feat: update to 0.9.2 (fixes rh#2126115 fixes rhbz#2121065)

* Fri Jul 22 2022 Fedora Release Engineering <releng@fedoraproject.org> - 0.9.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_37_Mass_Rebuild

* Mon Jul 04 2022 Python Maint <python-maint@redhat.com> - 0.9.1-2
- Rebuilt for Python 3.11

* Thu May 05 2022 Ankur Sinha (Ankur Sinha Gmail) <sanjay.ankur@gmail.com> - 0.9.1-1
- feat: update to 0.9.1

* Fri Apr 29 2022 Ankur Sinha (Ankur Sinha Gmail) <sanjay.ankur@gmail.com> - 0.9.0-4
- improvement: explicitly mention arm32

* Fri Apr 29 2022 Ankur Sinha (Ankur Sinha Gmail) <sanjay.ankur@gmail.com> - 0.9.0-3
- fix: also disable failing tests on arm32

* Thu Apr 28 2022 Ankur Sinha (Ankur Sinha Gmail) <sanjay.ankur@gmail.com> - 0.9.0-2
- fix: disable few failing tests on necessary arches

* Mon Feb 21 2022 Ankur Sinha (Ankur Sinha Gmail) <sanjay.ankur@gmail.com> - 0.9.0-1
- feat: update to 0.9.0 (fixes rhbz#2047860)

* Fri Jul 23 2021 Fedora Release Engineering <releng@fedoraproject.org> - 0.7.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_35_Mass_Rebuild

* Fri Jun 04 2021 Python Maint <python-maint@redhat.com> - 0.7.1-2
- Rebuilt for Python 3.10

* Sun Mar 28 2021 Ankur Sinha <ankursinha AT fedoraproject DOT org> - 0.7.1-1
- Update to latest release

* Wed Jan 27 2021 Fedora Release Engineering <releng@fedoraproject.org> - 0.7.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_34_Mass_Rebuild

* Sat Nov 28 2020 Ankur Sinha <ankursinha AT fedoraproject DOT org> - 0.7.0-1
- Update to latest release

* Wed Jul 29 2020 Fedora Release Engineering <releng@fedoraproject.org> - 0.6.2-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Thu Jun 25 2020 Ankur Sinha <ankursinha AT fedoraproject DOT org> - 0.6.2-3
- Explicitly BR setuptools

* Tue May 26 2020 Miro Hrončok <mhroncok@redhat.com> - 0.6.2-2
- Rebuilt for Python 3.9

* Wed Apr 22 2020 Ankur Sinha <ankursinha AT fedoraproject DOT org> - 0.6.2-1
- Update to 0.6.2

* Thu Feb 13 2020 Ankur Sinha <ankursinha AT fedoraproject DOT org> - 0.6.1-2
- Remove dummy sklearn requirement from setup.py
- Remove py2 bits from spec

* Sun Feb 02 2020 Ankur Sinha <ankursinha AT fedoraproject DOT org> - 0.6.1-1
- Update to newest version

* Thu Jan 30 2020 Fedora Release Engineering <releng@fedoraproject.org> - 0.5.2-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_32_Mass_Rebuild

* Mon Aug 19 2019 Miro Hrončok <mhroncok@redhat.com> - 0.5.2-3
- Rebuilt for Python 3.8

* Fri Jul 26 2019 Fedora Release Engineering <releng@fedoraproject.org> - 0.5.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_31_Mass_Rebuild

* Mon May 27 2019 Luis Bazan <lbazan@fedoraproject.org> - 0.5.2-1
- Update to 0.5.2

* Sun Apr 14 2019 Manas Mangaonkar <pac23@fedoraproject.org> - 0.5.1-1
- Update to 0.5.1

* Wed Apr 10 2019 Ankur Sinha <ankursinha@fedoraproject.org> - 0.5.0-1
- Update to 0.5.0

* Sat Feb 02 2019 Fedora Release Engineering <releng@fedoraproject.org> - 0.4.2-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Fri Nov 09 2018 Ankur Sinha <ankursinha@fedoraproject.org> - 0.4.2-2
- Correct license
- Remvoe shebangs
- Remove pre-compiled files

* Thu Nov 08 2018 Ankur Sinha <ankursinha@fedoraproject.org> - 0.4.2-1
- Initial build


## END: Generated by rpmautospec
